cytoflow.utility package
========================

Subpackages
-----------

.. toctree::

    cytoflow.utility.logicle_ext

Submodules
----------

cytoflow.utility.algorithms module
----------------------------------

.. automodule:: cytoflow.utility.algorithms
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.custom_traits module
-------------------------------------

.. automodule:: cytoflow.utility.custom_traits
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.cytoflow_errors module
---------------------------------------

.. automodule:: cytoflow.utility.cytoflow_errors
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.hlog_scale module
----------------------------------

.. automodule:: cytoflow.utility.hlog_scale
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.linear_scale module
------------------------------------

.. automodule:: cytoflow.utility.linear_scale
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.log_scale module
---------------------------------

.. automodule:: cytoflow.utility.log_scale
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.logicle_scale module
-------------------------------------

.. automodule:: cytoflow.utility.logicle_scale
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.matplotlib_widgets module
------------------------------------------

.. automodule:: cytoflow.utility.matplotlib_widgets
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.scale module
-----------------------------

.. automodule:: cytoflow.utility.scale
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.utility.util_functions module
--------------------------------------

.. automodule:: cytoflow.utility.util_functions
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflow.utility
    :members:
    :undoc-members:
    :show-inheritance:
